@@ -29,6 +29,10 @@ try:
     import syslog
 except ImportError:
     syslog = None
+try:
+    from systemd import journal
+except ImportError:
+    journal = None
 import tempfile
 import time
 from unittest import mock
@@ -65,26 +69,15 @@ handlers=
 
 
 def _fake_context():
-    ctxt = context.RequestContext(1, 1, overwrite=True)
-    ctxt.user = 'myuser'
-    ctxt.tenant = 'mytenant'
-    ctxt.domain = 'mydomain'
-    ctxt.project_domain = 'myprojectdomain'
-    ctxt.user_domain = 'myuserdomain'
-
-    return ctxt
-
-
-def _fake_new_context():
-    # New style contexts have a user_name / project_name, this is done
-    # distinctly from the above context to not have to rewrite all the
-    # other tests.
-    ctxt = context.RequestContext(1, 1, overwrite=True)
-    ctxt.user_name = 'myuser'
-    ctxt.project_name = 'mytenant'
-    ctxt.domain = 'mydomain'
-    ctxt.project_domain = 'myprojectdomain'
-    ctxt.user_domain = 'myuserdomain'
+    ctxt = context.RequestContext(user_id="myuser",
+                                  user_name="myuser",
+                                  system_scope="myscope",
+                                  domain="mydomain",
+                                  project_id="mytenant",
+                                  project_name="mytenant",
+                                  project_domain_id="mydomain",
+                                  user_domain_id="myuserdomain",
+                                  overwrite=True)
 
     return ctxt
 
@@ -104,7 +97,7 @@ class CommonLoggerTestsMixIn(object):
         log.register_options(self.config_fixture.conf)
         self.config(logging_context_format_string='%(asctime)s %(levelname)s '
                                                   '%(name)s [%(request_id)s '
-                                                  '%(user)s %(tenant)s] '
+                                                  '%(user)s %(project)s] '
                                                   '%(message)s')
         self.log = None
         log._setup_logging_from_conf(self.config_fixture.conf, 'test', 'test')
@@ -390,16 +383,27 @@ class OSJournalHandlerTestCase(BaseTestCase):
         self.addCleanup(self.journal.stop)
         log.setup(self.CONF, 'testing')
 
+    @testtools.skipUnless(journal, "systemd journal binding is not available")
+    def test_handler(self):
+        handler = handlers.OSJournalHandler()
+        handler.emit(
+            logging.LogRecord("foo", logging.INFO,
+                              "path", 123, "hey!",
+                              None, None))
+        self.assertTrue(self.journal.send.called)
+
     def test_emit(self):
         logger = log.getLogger('nova-test.foo')
-        local_context = _fake_new_context()
+        local_context = _fake_context()
         logger.info("Foo", context=local_context)
         self.assertEqual(
             mock.call(mock.ANY, CODE_FILE=mock.ANY, CODE_FUNC='test_emit',
                       CODE_LINE=mock.ANY, LOGGER_LEVEL='INFO',
                       LOGGER_NAME='nova-test.foo', PRIORITY=6,
+                      SYSLOG_FACILITY=syslog.LOG_USER,
                       SYSLOG_IDENTIFIER=mock.ANY,
                       REQUEST_ID=mock.ANY,
+                      PROJECT_ID='mytenant',
                       PROJECT_NAME='mytenant',
                       PROCESS_NAME='MainProcess',
                       THREAD_NAME='MainThread',
@@ -410,14 +414,15 @@ class OSJournalHandlerTestCase(BaseTestCase):
         self.assertIsInstance(args[0], str)
         self.assertIsInstance(kwargs['CODE_LINE'], int)
         self.assertIsInstance(kwargs['PRIORITY'], int)
-        del kwargs['CODE_LINE'], kwargs['PRIORITY']
+        self.assertIsInstance(kwargs['SYSLOG_FACILITY'], int)
+        del kwargs['CODE_LINE'], kwargs['PRIORITY'], kwargs['SYSLOG_FACILITY']
         for key, arg in kwargs.items():
             self.assertIsInstance(key, str)
             self.assertIsInstance(arg, (bytes, str))
 
     def test_emit_exception(self):
         logger = log.getLogger('nova-exception.foo')
-        local_context = _fake_new_context()
+        local_context = _fake_context()
         try:
             raise Exception("Some exception")
         except Exception:
@@ -427,10 +432,12 @@ class OSJournalHandlerTestCase(BaseTestCase):
                       CODE_FUNC='test_emit_exception',
                       CODE_LINE=mock.ANY, LOGGER_LEVEL='ERROR',
                       LOGGER_NAME='nova-exception.foo', PRIORITY=3,
+                      SYSLOG_FACILITY=syslog.LOG_USER,
                       SYSLOG_IDENTIFIER=mock.ANY,
                       REQUEST_ID=mock.ANY,
                       EXCEPTION_INFO=mock.ANY,
                       EXCEPTION_TEXT=mock.ANY,
+                      PROJECT_ID='mytenant',
                       PROJECT_NAME='mytenant',
                       PROCESS_NAME='MainProcess',
                       THREAD_NAME='MainThread',
@@ -441,7 +448,8 @@ class OSJournalHandlerTestCase(BaseTestCase):
         self.assertIsInstance(args[0], str)
         self.assertIsInstance(kwargs['CODE_LINE'], int)
         self.assertIsInstance(kwargs['PRIORITY'], int)
-        del kwargs['CODE_LINE'], kwargs['PRIORITY']
+        self.assertIsInstance(kwargs['SYSLOG_FACILITY'], int)
+        del kwargs['CODE_LINE'], kwargs['PRIORITY'], kwargs['SYSLOG_FACILITY']
         for key, arg in kwargs.items():
             self.assertIsInstance(key, str)
             self.assertIsInstance(arg, (bytes, str))
@@ -607,7 +615,7 @@ class JSONFormatterTestCase(LogTestBase):
         expected = b'\\u2622'
         # see ContextFormatterTestCase.test_can_process_strings
         expected = '\\\\xe2\\\\x98\\\\xa2'
-        self.log.info(b'%s', u'\u2622'.encode('utf8'))
+        self.log.info(b'%s', '\u2622'.encode('utf8'))
         self.assertIn(expected, self.stream.getvalue())
 
     def test_exception(self):
@@ -947,12 +955,12 @@ class ContextFormatterTestCase(LogTestBase):
                                                   "%(user_identity)s]: "
                                                   "%(message)s")
         ctxt = _fake_context()
-        ctxt.request_id = u'99'
+        ctxt.request_id = '99'
         message = 'test'
         self.log.info(message, context=ctxt)
-        expected = ("HAS CONTEXT [%s %s %s %s %s %s]: %s\n" %
-                    (ctxt.request_id, ctxt.user, ctxt.tenant, ctxt.domain,
-                     ctxt.user_domain, ctxt.project_domain,
+        expected = ("HAS CONTEXT [%s %s %s %s %s %s %s]: %s\n" %
+                    (ctxt.request_id, ctxt.user, ctxt.project_id, ctxt.domain,
+                     ctxt.system_scope, ctxt.user_domain, ctxt.project_domain,
                      str(message)))
         self.assertEqual(expected, self.stream.getvalue())
 
@@ -962,13 +970,13 @@ class ContextFormatterTestCase(LogTestBase):
                                                   "%(user_identity)s]: "
                                                   "%(message)s",
                     logging_user_identity_format="%(user)s "
-                                                 "%(tenant)s")
+                                                 "%(project)s")
         ctxt = _fake_context()
-        ctxt.request_id = u'99'
+        ctxt.request_id = '99'
         message = 'test'
         self.log.info(message, context=ctxt)
         expected = ("HAS CONTEXT [%s %s %s]: %s\n" %
-                    (ctxt.request_id, ctxt.user, ctxt.tenant,
+                    (ctxt.request_id, ctxt.user, ctxt.project_id,
                      str(message)))
         self.assertEqual(expected, self.stream.getvalue())
 
@@ -1007,7 +1015,7 @@ class ContextFormatterTestCase(LogTestBase):
         # or it will fail and inserting byte string in unicode string
         # causes such formatting
         expected = '\\xe2\\x98\\xa2'
-        self.log.info(b'%s', u'\u2622'.encode('utf8'))
+        self.log.info(b'%s', '\u2622'.encode('utf8'))
         self.assertIn(expected, self.stream.getvalue())
 
     def test_dict_args_with_unicode(self):
@@ -1247,7 +1255,11 @@ class DomainTestCase(LogTestBase):
         super(DomainTestCase, self).setUp()
         self.config(logging_context_format_string="[%(request_id)s]: "
                                                   "%(user_identity)s "
-                                                  "%(message)s")
+                                                  "%(message)s",
+                    logging_user_identity_format="%(user)s %(project)s "
+                                                 "%(user_domain)s "
+                                                 "%(project_domain)s "
+                                                 "%(domain)s")
         self.mylog = log.getLogger()
         self._add_handler_with_cleanup(self.mylog)
         self._set_log_level_with_cleanup(self.mylog, logging.DEBUG)
@@ -1266,7 +1278,8 @@ class DomainTestCase(LogTestBase):
 
     def test_domain_in_log_msg(self):
         ctxt = _fake_context()
-        user_identity = ctxt.get_logging_values()['user_identity']
+        user_identity = (self.CONF.logging_user_identity_format %
+                         ctxt.get_logging_values())
         self.assertIn(ctxt.domain, user_identity)
         self.assertIn(ctxt.project_domain, user_identity)
         self.assertIn(ctxt.user_domain, user_identity)
@@ -1906,7 +1919,7 @@ class KeywordArgumentAdapterTestCase(BaseTestCase):
 
 class UnicodeConversionTestCase(BaseTestCase):
 
-    _MSG = u'Message with unicode char \ua000 in the middle'
+    _MSG = 'Message with unicode char \ua000 in the middle'
 
     def test_ascii_to_unicode(self):
         msg = self._MSG
